#!/bin/bash
# By Linc 10/1/2004
# Find the latest script at http://linc.homeunix.org:8080/scripts/bashpodder
# Last revision 12/14/2004 - Many Contributers!
# If you use this and have made improvements or have comments
# drop me an email at linc dot fessenden at gmail dot com
# I'd appreciate it!

# Alterations for KPodder Leon Pennington 12/03/2006
# mainly adding options so we can change what files get processed, and where
# things are stored

# create name and create if neccessary the directory you want podcasts saved to
subDir()
{
    case $subdirType in
        0 ) datadir=$outputDir/$(date +%Y-%m-%d) ;;
        1 ) datadir=$outputDir/$1 ;;
        2 ) datadir=$outputDir/$(date +%Y-%m-%d)/$1 ;;
        3 ) datadir=$outputDir/$1/$(date +%Y-%m-%d) ;;
    esac
    # Check for and create datadir if necessary
    if test ! -d "$datadir"; then
        mkdir "$datadir"
    fi
}

# the work horse of the script
getCasts()
{
    file=$(wget -q $1 -O - | tr '\r' '\n' | tr \' \" | sed -n 's/.*url="\([^"]*\)".*/\1/p')
    for url in $file; do
        echo $url >> "$outputDir/temp.log"
        if ! grep "$url" "$logFile" > /dev/null; then
            echo "Downloading $url"
            wget -q -P "$datadir" "$url"
        fi
    done
}

# check theres something to process
if [ $# -eq 0 ]; then
    echo "Missing options"
    exit -1
fi

# working out the options
while getopts c:s:o:d:f:n: opt "$@"
do
    case $opt in
        #sets the configuration directory
        c ) confDir=$OPTARG;;
        #set the source file either a list or a single cast
        s ) sourceFile=$OPTARG;;
        f ) feedUrl=$OPTARG;;
        n ) feedName=$OPTARG;;
        #set the root data directory
        o ) outputDir=$OPTARG;;
        #set the sub directory type
        d ) subdirType=$OPTARG;;
        *)
            echo "Bad options supplied"
            exit -1
        ;;
    esac
done
shift `expr $OPTIND - 1`

if [[ -z $confDir || -z $outputDir || -z $subdirType || ( -z $sourceFile && ( -z $feedUrl || -z $feedName )) ]]; then
    echo "One or more of the required arguments is missing"
    exit  -1
fi

#set the fullpath file names
logFile=$confDir/podcast.log
sourceFile=$confDir/$sourceFile

#check for and create output directory if necessary
if test ! -d "$outputDir"; then
    mkdir -p "$outputDir"
fi

# Delete any temp file:
rm -f "$outputDir/temp.log"


if [ -z $feedUrl ]; then
    # Read the casts file and wget any url not already in the podcast.log file:
    while read line; do
        sep=
        for(( i=0; i<${#line}; ++i )); do
            if [ ${line:i:8} = "<kpname>" ]; then
                sep=i
                break
            fi
        done

        if [ -z $sep ]; then
            echo "Bad entry in casts list file"
            exit -1
        fi

        podcast=${line:0:$((sep))}
        castname=${line:$((sep+8))}

        echo "Checking casts from \"$castname\""
        subDir "$castname"

        getCasts $podcast

        echo "Building Playlist"
        ls "$datadir" | grep -v m3u > "$datadir/podcast.m3u"

    done < "$sourceFile"
else
    echo "Checking casts from \"$feedName\""
    subDir "$feedName"

    getCasts $feedUrl

    echo "Building Playlist"
    ls "$datadir" | grep -v m3u > "$datadir/podcast.m3u"
fi

# Move dynamically created log file to permanent log file:
cat "$logFile" >> "$outputDir/temp.log"
sort "$outputDir/temp.log" | uniq > "$logFile"
rm "$outputDir/temp.log"
